==> pointpos_api-0.0.16.tar.gz: test/customer_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for CustomerApi
void main() {
  var instance = new CustomerApi();

  group('tests for CustomerApi', () {
    // Create Customer
    //
    // Create Customer
    //
    //Future<Customer> createCustomer(String authorization, String xAPIKey, Customer body, { String xPin }) async 
    test('test createCustomer', () async {
      // TODO
    });

    // Delete Customer By ID
    //
    // Delete Customer By ID
    //
    //Future deleteCustomerByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteCustomerByID', () async {
      // TODO
    });

    // Get Customer List
    //
    // Get Customer  List
    //
    //Future<List<Customer>> findCustomer(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findCustomer', () async {
      // TODO
    });

    // Get Customer By ID
    //
    // Get Customer By ID
    //
    //Future<Customer> getCustomerByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getCustomerByID', () async {
      // TODO
    });

    // Update Customer By ID
    //
    // Update [object Object] By ID
    //
    //Future<Customer> updateCustomerByID(String authorization, String xAPIKey, String id, Customer body, { String xPin }) async 
    test('test updateCustomerByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.1.tar.gz: test/customer_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for CustomerApi
void main() {
  var instance = new CustomerApi();

  group('tests for CustomerApi', () {
    // Create Customer
    //
    // Create Customer
    //
    //Future<Customer> createCustomer(String authorization, String xAPIKey, Customer body, { String xPin }) async 
    test('test createCustomer', () async {
      // TODO
    });

    // Delete Customer By ID
    //
    // Delete Customer By ID
    //
    //Future deleteCustomerByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteCustomerByID', () async {
      // TODO
    });

    // Get Customer List
    //
    // Get Customer  List
    //
    //Future<List<Customer>> findCustomer(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findCustomer', () async {
      // TODO
    });

    // Get Customer By ID
    //
    // Get Customer By ID
    //
    //Future<Customer> getCustomerByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getCustomerByID', () async {
      // TODO
    });

    // Update Customer By ID
    //
    // Update [object Object] By ID
    //
    //Future<Customer> updateCustomerByID(String authorization, String xAPIKey, String id, Customer body, { String xPin }) async 
    test('test updateCustomerByID', () async {
      // TODO
    });

  });
}
